@@ -2,7 +2,7 @@ from dataclasses import dataclass
 from datetime import datetime
 from dateutil import parser
 import functools
-from typing import Any, List, Optional
+from typing import Any, List, Optional, Dict
 from dacite import from_dict, config
 from requests import Response, Session
 from urllib.parse import quote as sanitize_param
@@ -55,6 +55,10 @@ def deserialize_list(json: List[Any], dataclass):
     return [deserialize_one(element, dataclass) for element in json]
 
 
+def deserialize_dict(json: Dict[Any, Any], key_dataclass, value_dataclass):
+    return {deserialize(key, key_dataclass): deserialize(value, value_dataclass) for key, value in json.items()}
+
+
 def _safe_get_json(response: Optional[Response]):
     try:
         return response.json()
